.. _github_admins:

*************
GitHub Admins
*************

.. contents:: Topics

GitHub Admins have more permissions on GitHub than normal contributors or even committers.  There are
a few responsibilities that come with that increased power.


Adding and removing committers
==============================

The Ansible Team will periodically review who is actively contributing to Ansible to grant or revoke
contributors' ability to commit on their own.  GitHub Admins are the people who have the power to
actually manage the GitHub permissions.


Changing branch permissions for releases
========================================

When we make releases we make people go through a :ref:`release_managers` to push commits to that
branch.  The GitHub admins are responsible for setting the branch so only the Release Manager can
commit to the branch when the release process reaches that stage and later opening the branch once
the release has been made.  The Release manager will let the GitHub Admin know when this needs to be
done.

.. seealso:: The `GitHub Admin Process Docs
    <https://docs.google.com/document/d/1gWPtxNX4J39uIzwqQWLIsTZ1dY_AwEZzAd9bJ4XtZso/edit#heading=h.2wezayw9xsqz>`_ for instructions
    on how to change branch permissions.
